# QiitaCLI

[![Build Status](https://travis-ci.org/mypaceshun/qiitacli.svg?branch=master)](https://travis-ci.org/mypaceshun/qiitacli)
[![codecov](https://codecov.io/gh/mypaceshun/qiitacli/branch/master/graph/badge.svg)](https://codecov.io/gh/mypaceshun/qiitacli)



Qiita CUI Client

CUIでQiitaの投稿をしたくて作ったもの
Qiitaの記事を投稿出来るようになるのが目標
